@@ -39,14 +39,14 @@ class API:
                 if result_json['error']['code'] in [4, 700]:
                     eventlet.sleep(5)
                     return self.api_call(method, args)
-                if result_json['error']['code'] == 100: raise ItemsLimitExceededException
-                if result_json['error']['code'] == 200: raise PermissionException
-                if result_json['error']['code'] == 300: raise InvalidTokenException
-                if result_json['error']['code'] == 500: raise WrongParameterException
-                if result_json['error']['code'] == 501: raise MissingParameterException
-                if result_json['error']['code'] == 600: raise InvalidQueryException
-                if result_json['error']['code'] == 800: raise DataException
-                if result_json['error']['code'] == 901: raise IndividualAccountChangedNotAllowedException
+                if result_json['error']['code'] == 100: raise ItemsLimitExceededException(f"ItemsLimitExceededException: {method}")
+                if result_json['error']['code'] == 200: raise PermissionException(f"PermissionException: {method}")
+                if result_json['error']['code'] == 300: raise InvalidTokenException(f"InvalidTokenException: {method}")
+                if result_json['error']['code'] == 500: raise WrongParameterException(f"ParameterException: {method}")
+                if result_json['error']['code'] == 501: raise MissingParameterException(f"MissingParameterException: {method}")
+                if result_json['error']['code'] == 600: raise InvalidQueryException(f"InvalidQueryException: {method}")
+                if result_json['error']['code'] == 800: raise DataException(f"DataException: {method}")
+                if result_json['error']['code'] == 901: raise IndividualAccountChangedNotAllowedException(f"IndividualAccountChangedNotAllowedException: {method}")
             raise APIError(json.dumps(result_json['error']))
         return result_json
 
@@ -216,15 +216,15 @@ class API:
 
     def search_radio(self, query, strict=False, order=None, index=0, limit=25):
         args = self._generate_search_args(query, strict, order, index, limit)
-        return self.api_call('search/playlist', radio)
+        return self.api_call('search/radio', args)
 
     def search_track(self, query, strict=False, order=None, index=0, limit=25):
         args = self._generate_search_args(query, strict, order, index, limit)
-        return self.api_call('search/track', radio)
+        return self.api_call('search/track', args)
 
     def search_user(self, query, strict=False, order=None, index=0, limit=25):
         args = self._generate_search_args(query, strict, order, index, limit)
-        return self.api_call('search/user', radio)
+        return self.api_call('search/user', args)
 
     def get_track(self, song_id):
         return self.api_call(f'track/{str(song_id)}')
@@ -265,7 +265,7 @@ class API:
     # Extra calls
 
     def get_countries_charts(self):
-        temp = self.get_user_playlists('637006841')
+        temp = self.get_user_playlists('637006841', limit=-1)['data']
         result = sorted(temp, key=lambda k: k['title']) # Sort all playlists
         if not result[0]['title'].startswith('Top'): result = result[1:] # Remove loved tracks playlist
         return result
